@@ -480,11 +480,12 @@ class TestCleaning(unittest.TestCase):
             'expected_meta': {
                 'AverageBitrate': 465641,
                 'BufferSize': 0,
-                'CompatibleBrands': ['isom', 'iso2', 'avc1', 'mp41'],
-                'ColorProfiles': 'nclx',
                 'ColorPrimaries': 'BT.709',
+                'ColorProfiles': 'nclx',
                 'ColorRepresentation': 'nclx 1 1 1',
+                'CompatibleBrands': ['isom', 'iso2', 'avc1', 'mp41'],
                 'CompressorID': 'avc1',
+                'CompressorName': 'JVT/AVC Coding',
                 'GraphicsMode': 'srcCopy',
                 'HandlerDescription': 'SoundHandler',
                 'HandlerType': 'Metadata',
@@ -495,6 +496,7 @@ class TestCleaning(unittest.TestCase):
                 'MediaDataOffset': 48,
                 'MediaDataSize': 379872,
                 'MediaHeaderVersion': 0,
+                'MediaLanguageCode': 'eng',
                 'MinorVersion': '0.2.0',
                 'MovieDataOffset': 48,
                 'MovieHeaderVersion': 0,
